# Music Playlists

Generates streaming music playlists create from various song charts.

## Playlists

### Triple J Unearthed Weekly ([Source](https://www.triplejunearthed.com/discover/charts))

- [Generated YouTube Music Playlist](https://music.youtube.com/playlist?list=PLxYyVSBSlflWEJroa8S-ICu4YNzVFQiVl)
- [Generated Spotify Playlist](https://open.spotify.com/playlist/1Fi0e7Bwof3ZZYKiTqIFeG)

Similar Playlists

- [Similar YouTube Music Playlist](https://music.youtube.com/playlist?list=PLFqO_oqoHHMwqcf99e0zeht2Gm0eOmrQx)
- [Similar Spotify Playlist by Triple J](https://open.spotify.com/playlist/78d1cKN9xYtKialnOYkI92)

### Triple J Most Played Daily ([Source](https://www.abc.net.au/triplej/featured-music/most-played/))

- [Generated YouTube Music Playlist](https://music.youtube.com/playlist?list=PLxYyVSBSlflXb3R7YIKDtJf015kzwSocB)
- [Generated Spotify Playlist](https://open.spotify.com/playlist/6fk0j4ncAVZgR0BGXgnoQP)

Similar Playlists

- [Similar YouTube Music Playlist](https://music.youtube.com/playlist?list=PLFqO_oqoHHMw8xPXfm2-SOrwXPEHSqoOf)
- [Similar Spotify Playlist by Triple J](https://open.spotify.com/playlist/7vFQNWXoblEJXpbnTuyz76)

### Double J Most Played Daily ([Source](https://www.abc.net.au/doublej/featured-music/most-played/))

- [Generated YouTube Music Playlist](https://music.youtube.com/playlist?list=PLxYyVSBSlflUUImfAqq7Y5kxliC5MZz8C)
- [Generated Spotify Playlist](https://open.spotify.com/playlist/5pMHkM6y47xeqKstXTxe5l)

Similar Playlists

- [Similar Spotify Playlist by Double J](https://open.spotify.com/playlist/3eVaP90RyWrOKu6Gejw5Eg)

### Radio 4zzz Weekly ([Source](http://4zzz.org.au/))

- [Generated YouTube Music Playlist](https://music.youtube.com/playlist?list=PLxYyVSBSlflVHDZXI5t0RV0zCl0kdYxTq)
- [Generated Spotify Playlist](https://open.spotify.com/playlist/6QXfh1GEnk5WZcgk6DYeFX)

### Last.fm Most Popular Weekly ([Source](https://www.last.fm/charts))

- [Generated YouTube Music Playlist](https://music.youtube.com/playlist?list=PLxYyVSBSlflWOVUsXTbIezz7JKWbvDU14)
- [Generated Spotify Playlist](https://open.spotify.com/playlist/2OG0mxQqwQ4y26f7lrFv7z)

### SoundCloud Trending Australia Weekly ([Source](https://soundcloud.com/charts/new?genre=all-music&country=AU))

Not available due to [Soundcloud closing access to API keys](https://github.com/soundcloud/api).

- [Generated YouTube Music Playlist](https://music.youtube.com/playlist?list=PLxYyVSBSlflVpfo0OvLXqvoynQMHon0ve)
- [Generated Spotify Playlist](https://open.spotify.com/playlist/5nBtYkUuLlbfOWc0Jy4s2E)

### Other playlists

- [Guardian Australia Monthly New Music](https://www.theguardian.com/music/series/australias-best-new-music):
  [Spotify](https://open.spotify.com/playlist/5Cw9qgG1EaqvJYYdhGC8JJ)
